#ifndef FUNCPROTOS_H
#define FUNCPROTOS_H

#include "config.h"
#include <graphics.h>

#include <lqt_funcprotos.h>
#include <quicktime/lqt_codecinfo.h>
// #include <cmodel_permutation.h>




#endif
